@@ -92,7 +92,7 @@
 #define FASTGLTF_QUOTE(x) FASTGLTF_QUOTE_Q(x)
 
 // fastgltf version string. Use FASTGLTF_QUOTE to stringify.
-#define FASTGLTF_VERSION 0.7.1
+#define FASTGLTF_VERSION 0.7.2
 
 namespace fastgltf {
 #if defined(FASTGLTF_USE_64BIT_FLOAT) && FASTGLTF_USE_64BIT_FLOAT
@@ -296,7 +296,7 @@ namespace fastgltf {
      */
     constexpr auto getNumComponents(AccessorType type) noexcept {
     	static_assert(std::is_same_v<std::underlying_type_t<AccessorType>, std::uint16_t>);
-        return static_cast<std::uint8_t>(to_underlying(type) >> 8U);
+        return static_cast<std::size_t>(to_underlying(type) >> 8U);
     }
 
     /**
@@ -306,15 +306,15 @@ namespace fastgltf {
         switch (type) {
             case AccessorType::Mat2:
             case AccessorType::Vec2:
-                return 2;
+                return std::size_t(2U);
             case AccessorType::Mat3:
             case AccessorType::Vec3:
-                return 3;
+                return std::size_t(3U);
             case AccessorType::Mat4:
             case AccessorType::Vec4:
-                return 4;
+                return std::size_t(4U);
             default:
-                return 1;
+                return std::size_t(1U);
         }
     }
 
@@ -324,7 +324,7 @@ namespace fastgltf {
 
     constexpr auto getComponentBitSize(ComponentType componentType) noexcept {
     	static_assert(std::is_same_v<std::underlying_type_t<ComponentType>, std::uint32_t>);
-    	return static_cast<std::uint16_t>(to_underlying(componentType) >> 16U);
+    	return static_cast<std::size_t>(to_underlying(componentType) >> 16U);
     }
 
     constexpr auto getElementByteSize(AccessorType type, ComponentType componentType) noexcept {
@@ -335,21 +335,23 @@ namespace fastgltf {
             // Matrices need extra padding per-column which affects their size.
             numComponents += rowCount * (4 - (rowCount % 4));
         }
-        return static_cast<std::size_t>(numComponents * componentSize);
+        return numComponents * componentSize;
     }
 
     /**
      * Returns the OpenGL component type enumeration for the given component type.
+     * All OpenGL enumerations use GLenum, which is a 32-bit wide integer, which is why
+     * this function returns a std::uint32_t.
      *
      * For example, getGLComponentType(ComponentType::Float) will return GL_FLOAT (0x1406).
      */
     constexpr auto getGLComponentType(ComponentType type) noexcept {
-    	static_assert(std::is_same_v<std::underlying_type_t<ComponentType>, std::uint32_t>);
-        return static_cast<std::uint16_t>(to_underlying(type));
+        static_assert(std::is_same_v<std::underlying_type_t<ComponentType>, std::uint32_t>);
+        return static_cast<std::uint32_t>(to_underlying(type) & 0xFFFF);
     }
 
     /**
-     * Don't use this, use getComponenType instead.
+     * Don't use this, use getComponentType instead.
      * This order matters as we assume that their glTF constant is ascending to index it.
      */
     static constexpr std::array<ComponentType, 11> components = {
@@ -367,7 +369,7 @@ namespace fastgltf {
     };
 
     constexpr auto getComponentType(std::underlying_type_t<ComponentType> componentType) noexcept {
-        const auto index = componentType - getGLComponentType(ComponentType::Byte);
+        const auto index = static_cast<std::size_t>(componentType - getGLComponentType(ComponentType::Byte));
         if (index >= components.size()) {
             return ComponentType::Invalid;
 		}
@@ -860,21 +862,13 @@ namespace fastgltf {
 
         [[nodiscard]] T& at(std::size_t idx) {
             if (idx >= size()) {
-#ifdef __cpp_exceptions
-                throw std::out_of_range("Index is out of range for SmallVector");
-#else
-				std::abort();
-#endif
+                fastgltf::raise<std::out_of_range>("Index is out of range for SmallVector");
             }
             return begin()[idx];
         }
         [[nodiscard]] const T& at(std::size_t idx) const {
             if (idx >= size()) {
-#ifdef __cpp_exceptions
-                throw std::out_of_range("Index is out of range for SmallVector");
-#else
-	            std::abort();
-#endif
+                fastgltf::raise<std::out_of_range>("Index is out of range for SmallVector");
             }
             return begin()[idx];
         }
@@ -1083,28 +1077,28 @@ namespace fastgltf {
 
 		[[nodiscard]] T& value()& {
 			if (!has_value()) {
-				throw std::bad_optional_access();
+                fastgltf::raise<std::bad_optional_access>();
 			}
 			return _value;
 		}
 
 		[[nodiscard]] const T& value() const& {
 			if (!has_value()) {
-				throw std::bad_optional_access();
+				fastgltf::raise<std::bad_optional_access>();
 			}
 			return _value;
 		}
 
 		[[nodiscard]] T&& value()&& {
 			if (!has_value()) {
-				throw std::bad_optional_access();
+				fastgltf::raise<std::bad_optional_access>();
 			}
 			return std::move(_value);
 		}
 
 		[[nodiscard]] const T&& value() const&& {
 			if (!has_value()) {
-				throw std::bad_optional_access();
+				fastgltf::raise<std::bad_optional_access>();
 			}
 			return std::move(_value);
 		}
@@ -1560,7 +1554,7 @@ namespace fastgltf {
         FASTGLTF_STD_PMR_NS::vector<std::pair<FASTGLTF_STD_PMR_NS::string, std::size_t>> instancingAttributes;
 
         FASTGLTF_STD_PMR_NS::string name;
- 
+
         [[nodiscard]] auto findInstancingAttribute(std::string_view attributeName) noexcept {
             for (auto it = instancingAttributes.begin(); it != instancingAttributes.end(); ++it) {
                 if (it->first == attributeName)
@@ -1931,7 +1925,7 @@ namespace fastgltf {
         AccessorType type;
         ComponentType componentType;
         bool normalized = false;
-        
+
         std::variant<std::monostate, FASTGLTF_STD_PMR_NS::vector<double>, FASTGLTF_STD_PMR_NS::vector<std::int64_t>> max;
         std::variant<std::monostate, FASTGLTF_STD_PMR_NS::vector<double>, FASTGLTF_STD_PMR_NS::vector<std::int64_t>> min;
 
