@@ -150,6 +150,15 @@ namespace fastgltf {
         return (a > b) ? a : b;
     }
 
+    template<typename T, typename... A>
+    [[noreturn]] constexpr void raise(A&&... args) {
+#ifdef __cpp_exceptions
+        throw T(std::forward<A>(args)...);
+#else
+        std::abort();
+#endif
+    }
+
     /**
      * Decomposes a transform matrix into the translation, rotation, and scale components. This
      * function does not support skew, shear, or perspective. This currently uses a quick algorithm
@@ -328,7 +337,7 @@ namespace fastgltf {
 	 * Helper type in order to allow building a visitor out of multiple lambdas within a call to
 	 * std::visit
 	 */
-	template<class... Ts> 
+	template<class... Ts>
 	struct visitor : Ts... {
 		using Ts::operator()...;
 	};
@@ -379,6 +388,18 @@ namespace fastgltf {
 		return dst;
 	}
 #endif
+
+	/**
+	 * Returns the absolute value of the given integer in its unsigned type.
+	 * This avoids the issue with two complementary signed integers not being able to represent INT_MIN.
+	 */
+	template <typename T>
+	constexpr std::make_unsigned_t<T> uabs(T val) {
+		using unsigned_t = std::make_unsigned_t<T>;
+		return (val < 0)
+			? static_cast<unsigned_t>(-(val + 1)) + 1
+			: static_cast<unsigned_t>(val);
+	}
 } // namespace fastgltf
 
 #ifdef _MSC_VER
