@@ -1,8 +1,11 @@
 #include <algorithm>
 #include <cstdint>
+#include <fstream>
 
 #include <catch2/catch_test_macros.hpp>
 
+#include <simdjson.h>
+
 #include <fastgltf/core.hpp>
 #include "gltf_path.hpp"
 
@@ -81,9 +84,16 @@ TEST_CASE("Try writing a glTF with all buffers and images", "[write-tests]") {
     auto cube = parser.loadGltfJson(&gltfDataBuffer, cubePath, options);
     REQUIRE(cube.error() == fastgltf::Error::None);
 
-    std::filesystem::create_directory(path / "export");
+	// Destroy the directory to make sure that the FileExporter correctly creates directories.
+	auto exportedFolder = path / "export";
+	if (std::filesystem::exists(exportedFolder)) {
+		std::error_code ec;
+		std::filesystem::remove_all(exportedFolder, ec);
+		REQUIRE(!ec);
+	}
+
     fastgltf::FileExporter exporter;
-    auto error = exporter.writeGltfJson(cube.get(), path / "export" / "cube.gltf",
+    auto error = exporter.writeGltfJson(cube.get(), exportedFolder / "cube.gltf",
                                         fastgltf::ExportOptions::PrettyPrintJson);
     REQUIRE(error == fastgltf::Error::None);
 }
@@ -99,10 +109,46 @@ TEST_CASE("Try writing a GLB with all buffers and images", "[write-tests]") {
     auto cube = parser.loadGltfJson(&gltfDataBuffer, cubePath, options);
     REQUIRE(cube.error() == fastgltf::Error::None);
 
-    std::filesystem::create_directory(path / "export_glb");
+	// Destroy the directory to make sure that the FileExporter correctly creates directories.
+	auto exportedFolder = path / "export_glb";
+	if (std::filesystem::exists(exportedFolder)) {
+		std::error_code ec;
+		std::filesystem::remove_all(exportedFolder, ec);
+		REQUIRE(!ec);
+	}
+
     fastgltf::FileExporter exporter;
-    auto error = exporter.writeGltfBinary(cube.get(), path / "export_glb" / "cube.glb");
+	auto exportedPath = exportedFolder / "cube.glb";
+    auto error = exporter.writeGltfBinary(cube.get(), exportedPath);
     REQUIRE(error == fastgltf::Error::None);
+
+	// Make sure the GLB buffer is written
+	std::error_code ec;
+	auto length = std::filesystem::file_size(exportedPath, ec);
+	std::ifstream glb(exportedPath, std::ios::binary);
+	REQUIRE(glb.is_open());
+
+	// Skip over the header
+	glb.seekg(sizeof(std::uint32_t) * 3, std::ifstream::beg);
+
+	// Read the chunk length
+	std::uint32_t chunkLength = 0;
+	glb.read(reinterpret_cast<char*>(&chunkLength), sizeof chunkLength);
+
+	// Skip over the chunk type + chunk
+	glb.seekg(sizeof(std::uint32_t) + fastgltf::alignUp(chunkLength, 4), std::ifstream::cur);
+
+	// Read binary chunk length
+	glb.read(reinterpret_cast<char*>(&chunkLength), sizeof chunkLength);
+	REQUIRE(chunkLength == cube->buffers.front().byteLength);
+
+	// Read & verify BIN chunk type id
+	std::array<std::uint8_t, 4> binType {};
+	glb.read(reinterpret_cast<char*>(binType.data()), sizeof binType);
+	REQUIRE(binType[0] == 'B');
+	REQUIRE(binType[1] == 'I');
+	REQUIRE(binType[2] == 'N');
+	REQUIRE(binType[3] == 0);
 }
 
 TEST_CASE("Test string escape", "[write-tests]") {
@@ -165,3 +211,52 @@ TEST_CASE("Test all local models and re-export them", "[write-tests]") {
 	}
 	std::printf("Successfully tested fastgltf exporter on %llu assets.", testedAssets);
 }
+
+TEST_CASE("Test URI normalization and removing backslashes", "[write-tests]") {
+#if FASTGLTF_CPP_20
+	auto unicodePath = sampleModels / "2.0" / std::filesystem::path(u8"Unicode❤♻Test") / "glTF";
+	fastgltf::GltfDataBuffer jsonData;
+	REQUIRE(jsonData.loadFromFile(unicodePath / std::filesystem::path(u8"Unicode❤♻Test.gltf")));
+#else
+	auto unicodePath = sampleModels / "2.0" / std::filesystem::u8path(u8"Unicode❤♻Test") / "glTF";
+	fastgltf::GltfDataBuffer jsonData;
+	REQUIRE(jsonData.loadFromFile(unicodePath / std::filesystem::u8path(u8"Unicode❤♻Test.gltf")));
+#endif
+
+	fastgltf::Parser parser;
+	auto asset = parser.loadGltfJson(&jsonData, unicodePath, fastgltf::Options::LoadExternalImages);
+	REQUIRE(asset.error() == fastgltf::Error::None);
+
+	REQUIRE(asset->images.size() == 1);
+	asset->images.front().name = "Unicode❤♻Texture";
+
+	// When exporting, we specify a redundant image base path to test if the normalization properly works.
+	// Additionally, on Windows we test if the slashes are changed properly.
+	fastgltf::Exporter exporter;
+#ifdef _WIN32
+	// When on Windows the default path separator is a backslash, but glTF requires a forward slash.
+	exporter.setImagePath(".\\textures1\\textures2\\..\\");
+#else
+	exporter.setImagePath("./textures1/textures2/../");
+#endif
+	auto exported = exporter.writeGltfJson(asset.get());
+
+	// Parse the JSON and inspect the image URI.
+	simdjson::ondemand::parser jsonParser;
+	simdjson::ondemand::document doc;
+	REQUIRE(jsonParser.iterate(exported.get().output.c_str(), exported.get().output.size(), exported.get().output.capacity()).get(doc) == simdjson::SUCCESS);
+
+	simdjson::ondemand::object object;
+	REQUIRE(doc.get_object().get(object) == simdjson::SUCCESS);
+
+	simdjson::ondemand::array images;
+	REQUIRE(doc["images"].get_array().get(images) == simdjson::SUCCESS);
+	REQUIRE(images.count_elements().value() == 1);
+
+	simdjson::ondemand::object imageObject;
+	REQUIRE(images.at(0).get_object().get(imageObject) == simdjson::SUCCESS);
+
+	std::string_view imageUri;
+	REQUIRE(imageObject["uri"].get_string().get(imageUri) == simdjson::SUCCESS);
+	REQUIRE(imageUri == "textures1/Unicode❤♻Texture.bin");
+}
